@@ -923,7 +923,7 @@ class MainWindow(AbstractQItem, QMainWindow, QAbstractYAMLObjectSingleton):
         self.statusbar.pixel_format_label.setText(f'{fmt.name} ')
 
         if output.got_timecodes:
-            times = sorted(set(output.timecodes))
+            times = sorted(set(d.to_fraction() for d in output.timecodes))
 
             if len(times) >= 2:
                 return self.statusbar.fps_label.setText(
